pub enum WorkerMessage {
DecodeFrame(FrameBuffer),
Flush,
Reset,
SetContext {
from_peer: String,
to_peer: String,
},
}Expand description
Messages that can be sent to the web worker
Variants
DecodeFrame(FrameBuffer)
Decode a frame
Flush
Flush the decoder buffer and reset state
Reset
Reset decoder to initial state (waiting for keyframe)
SetContext
Set diagnostic context so worker can tag events with original IDs